@@ -10,6 +10,8 @@ label and button texts of the container children
 are fully visible/displayed.
 
 """
+from typing import Callable
+
 from kivy.animation import Animation                                                        # type: ignore
 from kivy.core.window import Window                                                         # type: ignore
 # pylint: disable=no-name-in-module
@@ -18,7 +20,7 @@ from kivy.uix.label import Label
 from kivy.uix.widget import Widget                                                          # type: ignore
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
 class ContainerChildrenAutoWidthBehavior:
@@ -44,8 +46,10 @@ class ContainerChildrenAutoWidthBehavior:
     the window width changes.
 
     """
-    container: Widget           #: widget to add the dynamic children to (property provided by container or other mixin)
-    width: float                #: width of widget where an instance of this class get mixed-in (can be != container)
+    container: Widget           #: widget to add the dynamic children to (provided by the widget to be mixed into)
+    dispatch: Callable          #: event dispatch method, provided by the widget to be mixed into
+    opacity: float              #: opacity of the widget to be mixed into
+    width: float                #: width of the widget to be mixed into (mostly a parent of self.container)
 
     auto_width_anim_duration: float = NumericProperty(0.9)
     """ duration of the width animation in seconds.
@@ -85,6 +89,14 @@ class ContainerChildrenAutoWidthBehavior:
     _width_anim: Animation = None
     _complete_width: float = 0.0
 
+    def __init__(self, **kwargs):
+        # noinspection PyUnresolvedReferences
+        self.register_event_type('on_complete_opened')  # pylint: disable=maybe-no-member
+        super().__init__(**kwargs)
+
+    def on_complete_opened(self):
+        """ dispatch event when opening and width got determined. """
+
     def open(self, *_args, **kwargs):
         """ start optional open animation after calling open method if exists in inheriting container/layout widget.
 
@@ -97,16 +109,17 @@ class ContainerChildrenAutoWidthBehavior:
 
         if callable(getattr(super(), 'open', None)):
             # noinspection PyUnresolvedReferences
-            super().open(*_args, **kwargs)
+            super().open(*_args, **kwargs)      # pylint: disable=maybe-no-member
 
         if not hasattr(super(), 'container'):
             self.container = getattr(self, '_container', self)  # Popup has _container attribute, BoxLayout=self
 
         if anim_width:
             container_max_width = Window.width - self.auto_width_window_padding
-            self._width_anim = Animation(width=container_max_width, t='in_out_sine', d=self.auto_width_anim_duration)
+            self._width_anim = Animation(opacity=1.0, width=container_max_width,
+                                         t='in_out_sine', d=self.auto_width_anim_duration)
             self._width_anim.bind(on_progress=self._open_width_progress)
-            self._width_anim.bind(on_complete=self._win_width_bind)
+            self._width_anim.bind(on_complete=self._on_complete_opened)
             self.width = self.auto_width_start
             self._width_anim.start(self)
         else:
@@ -116,6 +129,8 @@ class ContainerChildrenAutoWidthBehavior:
         """ call to reset the last detected minimum container width (e.g. if the children text got changed). """
         self._complete_width = 0.0
 
+    # internal methods
+
     def _detect_complete_width(self) -> float:
         """ check clients textures until widest child texture got detected.
 
@@ -127,6 +142,12 @@ class ContainerChildrenAutoWidthBehavior:
                 self._complete_width = self.width
         return self._complete_width
 
+    def _on_complete_opened(self, *_args):
+        """ open animation completion callback/event. """
+        self.opacity = 1.0
+        self._win_width_bind()
+        self.dispatch('on_complete_opened')
+
     def _on_win_width(self, *_args):
         """ Window.width event handler. """
         self.width = min(max(self.auto_width_minimum, Window.width),
@@ -138,6 +159,6 @@ class ContainerChildrenAutoWidthBehavior:
             if self._detect_complete_width():
                 self._width_anim.stop(self)
 
-    def _win_width_bind(self, *_args):
+    def _win_width_bind(self):
         """ bind :class:`~kivy.core.window.Window` width property to container width. """
         Window.bind(width=self._on_win_width)
